securityheaders

package
v2.3.0+incompatible Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 25, 2020 License: Apache-2.0 Imports: 13 Imported by: 0

README

SecurityHeaders-Scan

The SecurityHeaders-Scan performs the scan provided by scotthelme (securityheaders.com)

Table Columns

Column Description
Grade Received Grade
XFrameOptions XFrameOptions-Header of the domain
StrictTransportSecurity HSTS-Header of the domain
XContentTypeOptions XContentTypeOptions-Header of the domain
XXSSProtection XXSSProtection-Header of the domain
ContentSecurityPolicy CSP-Header of the domain
ReferrerPolicy Referer Policy of the domain
FeaturePolicy FeaturePolicy of the domain
ExpectCT ExpectCT of the domain
ReportTo ReportTo of the domain
NEL NEL of the domain
ScanStatus Pending: 0, Done: 1, Ignored: 2, Error: 255

Configuration

Field Possible Values Description
Retries any positive Integer Numbers of Errors per Domain until the scan of this domain ultimately fails
ScanType 1-5 Defines for which Protocol the domain is scanned: 1 only HTTPS; 2 only HTTP; 3 Both; 4 Any but HTTPS is preferred; 5 Any but HTTP is preferred
ParallelScans any positive Integer Number of scans run simultaneous for this API
APILocation URL Base URL of the API
Hidden "on"/"off" If "on", results are not published on the website
FollowRedirect "on"/"off" If "on", the API follows redirects before scanning

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Config

type Config struct {
	Retries        int
	ScanType       int
	ParallelScans  int
	Hidden         string
	FollowRedirect string
	APILocation    string
}

CrawlerConfig

type TableRow

type TableRow struct {
	Grade                   string
	XFrameOptions           string
	StrictTransportSecurity string
	XContentTypeOptions     string
	XXSSProtection          string
	ContentSecurityPolicy   string
	ReferrerPolicy          string
	FeaturePolicy           string
	ExpectCT                string
	ReportTo                string
	NEL                     string
	ScanStatus              int
}

TableRow is the object used for unmarshaling the results by the API

Jump to